This module contains a definition of a new timestamp time, a “pair” or product.
Note: Its partial order trait is modified so that it follows a lexicographical order;
It is not truly partially ordered (cf. the compare_pairs test)!
Structs
- Pair
- A pair of timestamps, partially ordered by the product order.